.. :changelog:

History
-------

0.0.1 (2016-01-30)
---------------------

* First release on PyPI.

0.2.0 (2018-07-18)
------------------

"Beinn Dorain"

* New API for adding material to reports
* Full support for matplotlib plots
* Support for multiple data types in reports

0.3.0 (2020-03-02)
------------------

"Beinn an Dothaidh"

* Improved Python 3 support.
* Removed Python 2 support.
